function xySlice(d, nCols, pos, dir, nq)
% d - nimrod data structure
% nCols - number of columns in plot
% pos - number between 0 and 1 indicating axial or radial position of slice
% dir - 'x', or 'y' indicating direction to plot
% nq - array of integers specifying what to plot

% nq = 
%   1  - pressure
%   2  - density
%   3  - Te
%   4  - Ti
%   5  - Br
%   6  - Bz
%   7  - Bphi
%   8  - Ur
%   9  - Uz
%   10 - Uphi
%   11 - diff_shape

clrs='bkrgcmbkrgcmbkrgcmbkrgcmbkrgcm';

clearCurrentFigure;

% Set some defaults
if nargin < 5; nq = [1 2 3 6 8 11]; end
if nargin < 4; dir = 'x'; end
if nargin < 3; pos = 0.5; end
if nargin < 2; nCols = 2;end

nFigs = length(nq);
nRows = ceil(nFigs/nCols);

cb = makeCBstruct(d);
rz = combineBlocks2D(d.rb, cb, 'rz');
xMin = rz.f(1,1,1);
xMax = rz.f(1,end,1);
yMin = rz.f(2,1,1);
yMax = rz.f(2,1,end);

for nFig = 1:nFigs
    [p,nRow,nColumn] = getAxPos(nRows, nCols, nFig);
    if((nRow == nRows) | (nFig == nFigs)) bxAx = 1; else bxAx = 0; end
    hAx = axes('Position', p);
    if ~bxAx; set(gca,'xticklabel',''); end
    grid on;
    box on;
    if nFig == 1
        title(sprintf('t=%3.2g \\musec',1.e6*d.dump_time))
    end
    switch nq(nFig)
        case 1
            q=combineBlocks(d.rb,cb,'pres');
            n = 1;
            sLeg = 'Press';
        case 2
            q=combineBlocks(d.rb,cb,'nd');
            qeq=combineBlocks2D(d.rb,cb,'nd_eq');
            q.f(:,:,:,1) = q.f(:,:,:,1) + qeq.f;
            n = 1;
            sLeg = 'Density';
        case 3
            q=combineBlocks(d.rb,cb,'tele');
            n = 1;
            sLeg = 'Te';
        case 4
            q=combineBlocks(d.rb,cb,'tion');
            n = 1;
            sLeg = 'Ti';
        case 5
            q=combineBlocks(d.rb,cb,'be');
            n = 1;
            sLeg = 'Br';
        case 6
            q=combineBlocks(d.rb,cb,'be');
            n = 2;
            sLeg = 'Bz';
        case 7
            q=combineBlocks(d.rb,cb,'be');
            n = 3;
            sLeg = 'Bphi';
        case 8
            q=combineBlocks(d.rb,cb,'ve');
            n = 1;
            sLeg = 'Ur';
        case 9
            q=combineBlocks(d.rb,cb,'ve');
            n = 2;
            sLeg = 'Uz';
        case 10
            q=combineBlocks(d.rb,cb,'ve');
            n = 3;
            sLeg = 'Uphi';
        case 11
            q=combineBlocks2D(d.rb,cb,'diff_shape');
            n = 1;
            sLeg = 'ds';
        otherwise
    end
    
    [nv,nx,ny,nm]=size(q.f);
    
    nPos=length(pos);
    for nP = 1:nPos
        switch dir
            case 'x'
                ySlice = yMin + pos(nP)*(yMax - yMin);
                [ws,jSlice] = min(abs(rz.f(2,1,:)-ySlice));
            case 'y'
                xSlice = xMin + pos(nP)*(xMax - xMin);
                [ws,iSlice] = min(abs(rz.f(1,:,1)-xSlice));
            otherwise
                error('Illegal value for dir in xySlice');
        end

        switch dir
            case 'x'
                x = reshape(rz.f(1,:,jSlice),nx,1);
                y = reshape(q.f(n,:,jSlice,1),nx,1);
                xlim([xMin,xMax]);
            case 'y'
                x = reshape(rz.f(2,iSlice,:),ny,1);
                y = reshape( q.f(n,iSlice,:,1),ny,1);
                xlim([yMin,yMax]);
        end
            line(x, y,'color',clrs(nP));
            if nP == 1;legend(sLeg);end
    end
end
%--------------------------------------------------------------------------
function [p,nRow,nColumn]=getAxPos(nRows, nColumns, nAx)
% Define margins in structure m.
m.page.left = .03;
m.page.right = .01;
m.page.top = 0.05;
m.page.bottom = 0.05;
m.page.dX = (1.-m.page.left-m.page.right)/nColumns;
m.page.dY = (1.-m.page.top-m.page.bottom)/nRows;
m.axis.left = .03;
m.axis.right = .001;
m.axis.top = 0.02;
m.axis.bottom = 0.00;
m.axis.dX = m.page.dX - m.axis.right - m.axis.left;
m.axis.dY = m.page.dY - m.axis.top - m.axis.bottom;

%nRow = 1 + floor((nAx-1)/nColumns);
%nColumn = nAx - (nRow-1)*nColumns;
nColumn = ceil(nAx/nRows);
nRow = nAx - (nColumn-1)*nRows;

p(1) = m.page.left + m.axis.left + (nColumn-1)*m.page.dX;
p(2) = 1. - m.page.top - nRow*m.page.dY;
p(3) = m.axis.dX;
p(4) = m.axis.dY;

%--------------------------------------------------------------------------
function clearCurrentFigure
% Sometimes (like when there is a colorbar) 
%                               deleteing one child, kills siblings too
hChild = get(gcf, 'Children');
while ~isempty(hChild)
    delete(hChild(1));
    hChild = get(gcf, 'Children');
end
